print "1..10\n";

use Lingua::Romana::Perligata;

ECCE INTITULO PRIMUM SYNOPSIS

HOC EST EXEMPLUM

ECCE SECO

PER NEXTUM IN UNAM TUM X CONSCRIBEMENTIS FAC SIC
    NEXTUM OUTE.
CIS

ECCE INTITULO SECUNDUM TIUM ERUM

ECCE PROSUM COMMENT
HOC NON VIDETUR

ECCE INCIPIO COMMENT

NEQUE HOC

ECCE FINIO COMMENT

ECCE AD DEXTRAM

ECCE FACIO PUNCTUM

VENI

ECCE FACIO PUNCTUM

VIDI

ECCE FACIO PUNCTUM

VICI

ECCE AD SINISTRAM

ECCE SECO


OUTERE SIC
    SCRIBE EGRESSO ok TUM LACUNAM TUM NULLIMUM HORUM TUM NOVUMVERSUM.
CIS

ECCE AD DEXTRAM

    ECCE NUMERO PUNCTUM

    VENI

    ECCE NUMERO PUNCTUM

    VIDI

    ECCE NUMERO PUNCTUM

    VICI

ECCE AD SINISTRAM

ECCE AD DEXTRAM
    ECCE DEFINIO PRIMIS
    ECCE AD DEXTRAM
        ECCE FACIO PUNCTUM SIC...
        ECCE AD DEXTRAM
            ECCE NUMERO PUNCTUM VENI
            ECCE NUMERO PUNCTUM VIDI
            ECCE NUMERO PUNCTUM VICI
        ECCE AD SINISTRAM
        ECCE FACIO PUNCTUM SIC...
        ECCE AD DEXTRAM
            ECCE NUMERO PUNCTUM VENI
            ECCE NUMERO PUNCTUM VIDI
            ECCE NUMERO PUNCTUM VICI
        ECCE AD SINISTRAM
    ECCE AD SINISTRAM
ECCE AD SINISTRAM

