INCIPIO:;
use Lingua::Romana::Perligata;

SCRIBE EGRESSO UNUM TUM GUTTAM TUM GUTTAM TUM DUO TUM NOVUMVERSUM.

PARAMETRIS DA PROGRAMMA.

SI NULLIMUM PARAMETRORUM TUM PROGRAMMA AEQUALITAS FAC SIC
    SCRIBE EGRESSO DICTUM SIC ok CIS TUM STADIUM TUM UNUM TUM NOVUMVERSUM.
CIS.

DICTUM SIC INCIPIO CIS TUM BIGUTTAM TUM SEMICOLON TUM NOVUMVERSUM SEREMENTA DA MEO VERSO.

SI PARAMETRO PERLEGEMENTUM TUM VERSUM AEQUALITAS FAC SIC
    SCRIBE EGRESSO DICTUM SIC ok CIS TUM STADIUM TUM DUO TUM NOVUMVERSUM.
CIS.


